<?php

switch ($messaggio) {

case "situazione alle":  			$messaggio = "Situation am"; break;
case "del":  					$messaggio = "vom"; break;
case "Tabella prenotazioni del":  		$messaggio = "Reservierungstabelle von"; break;
case "ERRORE":  				$messaggio = "FEHLER"; break;
case "Torna al menù principale":  		$messaggio = "Hauptmen&uuml;"; break;
case "Visualizza la tabella normale":  		$messaggio = "Normale Tabelle anzeigen"; break;
case "Visualizza tutti i mesi":  		$messaggio = "Alle Monate anzeigen"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>